import { useSettingsStore } from '@/stores/settings'
import messages from '@intlify/unplugin-vue-i18n/messages'
import { createPinia } from 'pinia'
import piniaPluginPersistedstate from 'pinia-plugin-persistedstate'
import { createApp } from 'vue'
import { createI18n } from 'vue-i18n'
import App from './App.vue'

import router from './router'

import 'virtual:uno.css'

import '~console/theme-detect'

import '@unocss/reset/tailwind.css'

const app = createApp(App)
const pinia = createPinia()
pinia.use(piniaPluginPersistedstate)
app.use(pinia)

// Load store to retrieve language info
const settingsStore = useSettingsStore()

const i18n = createI18n({
  locale: settingsStore.language,
  fallbackLocale: ['en', 'de'],
  messages,
})

// Save changes of the locale to the store as the i18n cannot be accessed from the store
watch(i18n.global.locale, async (newValue) => {
  settingsStore.setLanguage(newValue)
})

// Must be called after pinia as it depends on a store
app.use(i18n)
app.use(router)

app.mount('#app')
